@@ -1,4 +1,4 @@
-// SPDX-License-Identifier: MIT OR Unlicense
+// SPDX-License-Identifier: MIT
 
 package processor
 
@@ -12,7 +12,7 @@ import (
 	"regexp"
 	"runtime"
 	"runtime/debug"
-	"sort"
+	"slices"
 	"strconv"
 	"strings"
 	"sync"
@@ -23,7 +23,7 @@ import (
 )
 
 // Version indicates the version of the application
-var Version = "3.3.5"
+var Version = "3.4.0"
 
 // Flags set via the CLI which control how the output is displayed
 
@@ -99,6 +99,9 @@ var Ci = false
 // GitIgnore disables .gitignore checks
 var GitIgnore = false
 
+// GitModuleIgnore disables .gitmodules checks
+var GitModuleIgnore = false
+
 // Ignore disables ignore file checks
 var Ignore = false
 
@@ -310,7 +313,7 @@ func ProcessConstants() {
 	}
 
 	// Fix for https://github.com/boyter/scc/issues/250
-	fixedPath := []string{}
+	fixedPath := make([]string, 0, len(PathDenyList))
 	for _, path := range PathDenyList {
 		fixedPath = append(fixedPath, strings.TrimRight(path, "/"))
 	}
@@ -532,14 +535,14 @@ func loadDatabase() map[string]Language {
 
 func printLanguages() {
 	database := loadDatabase()
-	var names []string
 
+	names := make([]string, 0, len(database))
 	for key := range database {
 		names = append(names, key)
 	}
 
-	sort.Slice(names, func(i, j int) bool {
-		return strings.Compare(strings.ToLower(names[i]), strings.ToLower(names[j])) < 0
+	slices.SortFunc(names, func(a, b string) int {
+		return strings.Compare(strings.ToLower(a), strings.ToLower(b))
 	})
 
 	for _, name := range names {
@@ -606,6 +609,7 @@ func Process() {
 	})
 	fileWalker.IgnoreGitIgnore = GitIgnore
 	fileWalker.IgnoreIgnoreFile = Ignore
+	fileWalker.IgnoreGitModules = GitModuleIgnore
 	fileWalker.IncludeHidden = true
 	fileWalker.ExcludeDirectory = PathDenyList
 
