@@ -1,16 +1,17 @@
-// SPDX-License-Identifier: MIT OR Unlicense
+// SPDX-License-Identifier: MIT
 
 package processor
 
 import (
 	"bytes"
 	"fmt"
-	"github.com/minio/blake2b-simd"
 	"hash"
 	"runtime/debug"
 	"strings"
 	"sync"
 	"sync/atomic"
+
+	"golang.org/x/crypto/blake2b"
 )
 
 // The below are used as identifiers for the code state machine
@@ -91,18 +92,11 @@ func isWhitespace(currentByte byte) bool {
 // Check if this file is binary by checking for nul byte and if so bail out
 // this is how GNU Grep, git and ripgrep check for binary files
 func isBinary(index int, currentByte byte) bool {
-	if index < 10000 && !DisableCheckBinary && currentByte == 0 {
-		return true
-	}
-
-	return false
+	return index < 10000 && !DisableCheckBinary && currentByte == 0
 }
 
 func shouldProcess(currentByte, processBytesMask byte) bool {
-	if currentByte&processBytesMask != currentByte {
-		return false
-	}
-	return true
+	return currentByte&processBytesMask == currentByte
 }
 
 func resetState(currentState int64) int64 {
@@ -406,7 +400,7 @@ func CountStats(fileJob *FileJob) {
 	// crypto secure here either so no need to eat the performance cost of a better
 	// hash method
 	if Duplicates {
-		fileJob.Hash = blake2b.New256()
+		fileJob.Hash, _ = blake2b.New256(nil)
 	}
 
 	// If the file has a length of 0 it is empty then we say it has no lines
@@ -563,10 +557,6 @@ func CountStats(fileJob *FileJob) {
 		}
 	}
 
-	if Duplicates {
-		fileJob.Hash.Sum(nil)
-	}
-
 	if UlocMode && Files {
 		uloc := map[string]struct{}{}
 		for _, l := range strings.Split(string(fileJob.Content), "\n") {
