@@ -650,6 +650,15 @@ else
     exit
 fi
 
+if ./scc -f json  -a | grep -q "ULOC"; then
+    echo -e "${GREEN}PASSED json uloc check"
+else
+    echo -e "${RED}======================================================="
+    echo -e "FAILED json uloc check"
+    echo -e "=======================================================${NC}"
+    exit
+fi
+
 if ./scc -f json2 | grep -q "Bytes"; then
     echo -e "${GREEN}PASSED json2 bytes check"
 else
@@ -906,9 +915,82 @@ else
 fi
 
 # Try out specific languages
-for i in 'Bosque ' 'Flow9 ' 'Bitbucket Pipeline ' 'Docker ignore ' 'Q# ' 'Futhark ' 'Alloy ' 'Wren ' 'Monkey C ' 'Alchemist ' 'Luna ' 'ignore ' 'XML Schema ' 'Web Services' 'Go ' 'Java ' 'Boo ' 'License ' 'BASH ' 'C Shell ' 'Korn Shell ' 'Makefile ' 'Shell ' 'Zsh ' 'Rakefile ' 'Gemfile ' 'Dockerfile ' 'Yarn ' 'Sieve ' 'F# ' 'Elm ' 'Terraform ' 'Clojure ' 'C# ' 'LLVM IR ' 'HAML ' 'FXML ' 'DM ' 'Nushell ' 'Racket ' 'DOT ' 'YAML ' 'Teal ' 'FSL ' 'INI ' 'Hare ' 'Templ ' 'Cuda ' 'GraphQL ' 'Bicep ' 'Pkl ' 'TypeSpec ' 'LALRPOP ' 'Snakemake ' 'OpenQASM ' 'Typst ' 'ZoKrates ' 'Chapel ' 'Slang ' 'Circom ' 'Proto ' 'wenyan ' 'Cangjie ' 'Clipper '
+specificLanguages=(
+    'Alchemist '
+    'Alloy '
+    'Arturo '
+    'AWK '
+    'BASH '
+    'Bicep '
+    'Bitbucket Pipeline '
+    'Boo '
+    'Bosque '
+    'C Shell '
+    'C# '
+    'Cairo '
+    'Cangjie '
+    'Chapel '
+    'Circom '
+    'Clipper '
+    'Clojure '
+    'Cuda '
+    'DM '
+    'Docker ignore '
+    'Dockerfile '
+    'DOT '
+    'Elm '
+    'F# '
+    'Factor '
+    'Flow9 '
+    'FSL '
+    'Futhark '
+    'FXML '
+    'Gemfile '
+    'Go '
+    'GraphQL '
+    'HAML '
+    'Hare '
+    'ignore '
+    'INI '
+    'Java '
+    'JSONC '
+    'Korn Shell '
+    'LALRPOP '
+    'License '
+    'LLVM IR '
+    'Luna '
+    'Makefile '
+    'Monkey C '
+    'Nushell '
+    'OpenQASM '
+    'Pkl '
+    'Proto '
+    'Q# '
+    'R '
+    'Racket '
+    'Rakefile '
+    'Shell '
+    'Sieve '
+    'Slang '
+    'Slint '
+    'Snakemake '
+    'Teal '
+    'Templ '
+    'Terraform '
+    'TypeSpec '
+    'Typst '
+    'Web Services '
+    'wenyan '
+    'Wren '
+    'XML Schema '
+    'YAML '
+    'Yarn '
+    'ZoKrates '
+    'Zsh '
+)
+for i in "${specificLanguages[@]}"
 do
-    if ./scc "examples/language/" | grep -q "$i "; then
+    if ./scc "examples/language/" | grep -q "$i"; then
         echo -e "${GREEN}PASSED $i Language Check"
     else
         echo -e "${RED}======================================================="
@@ -935,7 +1017,7 @@ done
 a=$(./scc "examples/issue345/" -f csv | sed -n '2 p')
 b="C++,4,3,1,0,0,76,1,0"
 if [ "$a" == "$b" ]; then
-    echo -e "{GREEN}PASSED string termination check"
+    echo -e "${GREEN}PASSED String Termination Check"
 else
     echo -e "$a"
     echo -e "${RED}======================================================="
@@ -944,6 +1026,41 @@ else
     exit
 fi
 
+# Regression issue https://github.com/boyter/scc/issues/379
+Issue379Line=$(./scc -f csv "examples/issue379/" | grep 'Python' | cut -d ',' -f 2)
+Issue379Code=$(./scc -f csv "examples/issue379/" | grep 'Python' | cut -d ',' -f 3)
+Issue379Comments=$(./scc -f csv "examples/issue379/" | grep 'Python' | cut -d ',' -f 4)
+Issue379Blanks=$(./scc -f csv "examples/issue379/" | grep 'Python' | cut -d ',' -f 5)
+Issue379Complexity=$(./scc -f csv "examples/issue379/" | grep 'Python' | cut -d ',' -f 6)
+if [ $Issue379Line -ne 7 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue379 line counting"
+    echo -e "=======================================================${NC}"
+    exit
+elif [ $Issue379Code -ne 4 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue379 code counting"
+    echo -e "=======================================================${NC}"
+    exit
+elif [ $Issue379Comments -ne 2 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue379 comments counting"
+    echo -e "=======================================================${NC}"
+    exit
+elif [ $Issue379Blanks -ne 1 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue379 blanks counting"
+    echo -e "=======================================================${NC}"
+    exit
+elif [ $Issue379Complexity -ne 1 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue379 complexity counting"
+    echo -e "=======================================================${NC}"
+    exit
+else
+    echo -e "${GREEN}PASSED Issue379 Regression Check"
+fi
+
 # Extra case for longer languages that are normally truncated
 for i in 'CloudFormation (YAM' 'CloudFormation (JSO'
 do
